#
# spec file for package php-pear-Net_Sieve
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define pear_name  Net_Sieve

Name:           php-pear-Net_Sieve
Version:        1.4.7
Release:        bp160.1.6
Summary:        PHP module for talking to a sieve server
License:        BSD-2-Clause
Group:          Development/Libraries/Other
URL:            https://pear.php.net/package/%{pear_name}
Source:         https://pear.php.net/get/%{pear_name}-%{version}.tgz
BuildRequires:  php-devel
BuildRequires:  php-pear
Requires:       php-pear
Requires:       php-pear(Net_Socket) >= 1.0
Recommends:     php-pear(Auth_SASL) >= 1.0
Provides:       php-pear(%{pear_name}) = %{version}
# PHP5 last used in openSUSE:Leap_42.3
Provides:       php5-pear-%{pear_name} = %{version}
Obsoletes:      php5-pear-%{pear_name} < %{version}
Provides:       php7-pear-%{pear_name} = %{version}
Obsoletes:      php7-pear-%{pear_name} < %{version}
BuildArch:      noarch

%description
This package provides an API to talk to servers implementing the managesieve protocol. It can be used to install and remove sieve scripts, mark them active etc.

%prep
%setup -q -n %{pear_name}-%{version}
# move package.xml when needed
[ -f ../package.xml ] &&  mv ../package.xml . || :

%build

%install
%{__pear} install --nodeps --offline --packagingroot %{buildroot} package.xml
install -D -m 0644 package.xml %{buildroot}%{php_pearxmldir}/%{pear_name}.xml

%{php_pear_gen_filelist}

%post
if [ "$1" = "1" ]; then
  # on "rpm -ivh"
  %{__pear} install --nodeps --soft --force --register-only %{php_pearxmldir}/%{pear_name}.xml || :
fi
if [ "$1" = "2" ]; then
  # on "rpm -Uvh"
  %{__pear} upgrade --offline --register-only %{php_pearxmldir}/%{pear_name}.xml || :
fi

%postun
if [ "$1" = "0" ]; then
  # on "rpm -e"
  %{__pear} uninstall --nodeps --ignore-errors --register-only pear.php.net/%{pear_name} || :
fi

%files -f %{name}.files
%docdir %{pear_docdir}
%exclude %{pear_metadir}/.??*
%exclude %{pear_testdir}

%changelog
* Sun May 26 2024 Arjen de Korte <suse+build@de-korte.org>
- New upstream release 1.4.7
  * Add support of OAUTHBEARER
  * PHPDoc improvements/fixes
  * Short array syntax
* Mon Dec 12 2022 Arjen de Korte <suse+build@de-korte.org>
- New upstream release 1.4.6
  * Fix PHP 8.1 deprecation warnings
* Sat Jun  5 2021 Arjen de Korte <suse+build@de-korte.org>
- New upstream release 1.4.5
  * Support XOAUTH2 authorization method
* Thu Dec  5 2019 Arjen de Korte <suse+build@de-korte.org>
- make package PHP version independent
- use correct macro to reference metadata (boo#1158112)
- clean-up spec, use https for downloading
* Sun Nov  4 2018 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in summary.
* Sun Nov  4 2018 Aeneas Jaißle <aj@ajaissle.de>
- New upstream release 1.4.4
  * Fix PHP 7.3: Declaration of case-insensitive constants is deprecated
- Changes 1.4.3:
  * Support GSSAPI authentication
- Changes 1.4.2:
  * Composer: Fix license identifier, don't use unbound version numbers for deps
* Mon Sep 11 2017 jweberhofer@weberhofer.at
- Fixed dependencies
- Simplified spec
* Sun Sep 10 2017 jweberhofer@weberhofer.at
- Cleaned up spec file
* Fri Aug 18 2017 ecsos@opensuse.org
- New upstream release 1.4.1
  * Use 8bit instead of latin1 for string length in bytes calculation
  * Extend listScripts() so it's possible to get an active script name in one go
  * Request #20491: Skip redundant CAPABILITY requests
- changes from 1.4.0
  * Dropped PHP4 support, fixed PHP7 warnings
  * Fixed E_DEPRECATED warning on Auth_SASL::factory() call
  * Enable later TLS versions
- renamed package to php7-pear-Net_Sieve
* Tue Sep 15 2015 aj@ajaissle.de
- New upstream release 1.3.4
  * Remove erroneous and unnecessary active script caching (Bug #20472)
- Changes 1.3.3:
  * Fix notices from non-static calling of PEAR methods.
  * Fix reading OK responses with string literal messages.
* Tue Dec 11 2012 Ralf Lang <lang@b1-systems.de>
- Fix dependency on php-macros for SLE11 case
* Thu Dec  8 2011 coolo@suse.com
- fix license to be in spdx.org format
* Wed Aug 24 2011 lang@b1-systems.de
- version 1.3.2
- Fix referrals if host data or user credentials are passed to connect() and login() instead of the constructor (Aleksander Machniak, Bug #17107).
- Query capabilities again after successful authentication (Jesse Crawford, Request #18382).
- Escape quotes and backslashes in script names, and use literal strings for script names with non-ASCII characters (Aleksander Machniak, Bug #16691).
- Work around broken STARTTLS behavior in Cyrus versions before 2.3.10 (Aleksander Machniak, Bug #18241).
- Improve string literal parsing (Aleksander Machniak, Bug #18228).
* Wed Jan 26 2011 lang@b1-systems.de
- packaged with php-macros
